﻿# call jmeter script to run test
#-n
#This specifies JMeter is to run in cli mode
#-t
#[name of JMX file that contains the Test Plan].
#-l
#[name of JTL file to log sample results to].
#-j
#[name of JMeter run log file].
#-r
#Run the test in the servers specified by the JMeter property "remote_hosts"
#-R
#[list of remote servers] Run the test in the specified remote servers
#-g
#[path to CSV file] generate report dashboard only
#-e
#generate report dashboard after load test
#-o
#output folder where to generate the report dashboard after load test. Folder must not exist or be empty
<#

.SYNOPSIS

Calling simple jmeter script to run test in CLI mode

.DESCRIPTION

Calling simple jmeter script to run test in CLI mode without parameters

.EXAMPLE

PS > ItsWeb-jemeter.ps1 -PathToTest "C:\Users\jmeter\tests\HomepageLoad.jmx"

this runs HomepageLoad.jmx test


#>
[CmdletBinding(DefaultParameterSetName = "Testing")]
param(
    [Parameter(HelpMessage = "Provide the path to jmx test")]
    [string]
    $PathToTest,    
    [Parameter(HelpMessage = "Provide the path store the result")]
    [string]
    $PathToOutput="C:\Work\Temp\"    
)

if (-not (Test-Path $PathToTest)) {
    Write-Error "Path to test $PathToTest does not exist"
    exit
}

if (Test-Path $PathToOutput) {
    Write-Error "Path to output $PathToOutput exist - folder needs to be empty to be able to store data"
    exit
}

Write-Output "Running JMeter test $PathToTest and saving data to $PathToOutput"

jmeter -n -t $PathToTest -e -o $PathToOutput -l loadtestresults.jtl

Write-Output "Report was generated and stored to $PathToOutput - opening for viewing loadtestresults.jtl"

Start-Process "notepad.exe" -ArgumentList loadtestresults.jtl

# entering variables or default values
#-D[prop_name]=[value]
#defines a java system property value.
#-J[prop_name]=[value]
#defines a local JMeter property.
#-G[prop_name]=[value]
#defines a JMeter property to be sent to all remote servers.
#-G[propertyfile]
#defines a file containing JMeter properties to be sent to all remote servers.
#-L[category]=[priority]
#overrides a logging setting, setting a particular category to the given priority level.