﻿using ALT;
using ALT.Shared;
using Azure.Core;
using Azure.Identity;
using Newtonsoft.Json;
using Spectre.Console;

var resourceGroupName = Environment.GetEnvironmentVariable("RESOURCEGROUP");
if (string.IsNullOrEmpty(resourceGroupName))
    resourceGroupName = AnsiConsole.Ask<string>("Enter the name of [green]resource group[/] in Azure?");

AnsiConsole.WriteLine($"Working with resource group {resourceGroupName}");
// var helper = new ALTService(new DefaultAzureCredential());
var helper = new ALTService(new AzurePowerShellCredential());
var resourceGroup = await helper.GetResourceGroupAsync(resourceGroupName, AzureLocation.WestEurope);

var loadTestResourceName = Environment.GetEnvironmentVariable("LOADTEST");
if (string.IsNullOrEmpty(loadTestResourceName))
    loadTestResourceName =
        AnsiConsole.Ask<string>("Enter the name of [green]Azure Load Test resource[/] in Azure?");

var quickTestEndpointUrl = Environment.GetEnvironmentVariable("TESTURL");
if (string.IsNullOrEmpty(quickTestEndpointUrl))
    quickTestEndpointUrl = AnsiConsole.Ask<string>("Enter the URL for quick [green]Azure Load Test[/] in Azure?");

var resource = await helper.GetLoadTestingResourceAsync(resourceGroup, loadTestResourceName,
    AzureLocation.WestEurope);
AnsiConsole.WriteLine($"Working with Azure Load Test {loadTestResourceName}");

// Get the data plane URI to manage and run load tests
var endpointUrl = new Uri("https://" + resource.Data.DataPlaneUri);
AnsiConsole.WriteLine($"Working with dataplane on {endpointUrl}.");

// Get the load test administration client
var loadTestAdministrationClient = helper.GetLoadTestAdminClient(endpointUrl);
// Create a quick test
var quickTestId =
    AnsiConsole.Ask<string>(
        "Enter the name of [green]quick test resource[/] (by default 'console-web-test')?",
        "console-web-test");

helper.GetQuickTest(loadTestAdministrationClient, quickTestId, quickTestEndpointUrl);

var appServiceName = Environment.GetEnvironmentVariable("APPSERVICENAME");
if (string.IsNullOrEmpty(appServiceName))
    appServiceName =
        AnsiConsole.Ask("Enter name of [green]service plan[/] in Azure, if you want to add server side metrics?",
            string.Empty);

if (!string.IsNullOrEmpty(appServiceName))
    await helper.CreateOrUpdateAppServiceComponentAsync(loadTestAdministrationClient,
        resourceGroupName,
        appServiceName,
        quickTestId);

// Run the load test
var info = helper.RunLoadTest(endpointUrl, quickTestId);
//Debug.WriteLine(info);
AnsiConsole.WriteLine("Test finished.");
if (!string.IsNullOrEmpty(info))
{
    var altTestResult = JsonConvert.DeserializeObject<AltTestResult>(info);
    AnsiConsole.WriteLine(
        $"{altTestResult.displayName} has been executed {altTestResult.createdDateTime} by {altTestResult.createdBy}");
    //Debug.WriteLine(altTestResult.portalUrl);
    BrowserHelper.OpenInDefaultBrowser(altTestResult.portalUrl);
}

AnsiConsole.WriteLine("Visit portal for latest information.");
AnsiConsole.Markup("[link]https://portal.azure.com[/]");