﻿using ALT.Shared;
using ALT.Web.Models;
using Azure.Identity;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;

namespace ALT.Web.Pages.Tests;

public class CreatePageModel : PageModel
{
    private readonly ILogger<CreatePageModel> logger;
    private readonly IWebHostEnvironment environment;

    public CreatePageModel(ILogger<CreatePageModel> logger, IWebHostEnvironment environment)
    {
        this.logger = logger;
        this.environment = environment;
    }

    public async Task OnGetAsync()
    {
        logger.LogInformation("Loaded create page at {DateCreated}", DateTime.Now);
        var altService = new ALTService(new AzurePowerShellCredential());
        var groupCollection = await altService.GetResourceGroupsAsync();
        logger.LogInformation("Getting {NumberOfResourceGroups} resource group in subscription",
            groupCollection.Count());
        var groups = await groupCollection.GetAllAsync().ToListAsync();
        foreach (var resourceGroupResource in groups)
        {
            ResourceGroups.Add(new ResourceGroupViewModel
            {
                Name = resourceGroupResource.Data.Name
            });
        }

        logger.LogInformation("Converted {ItemNumber} from api to local variables.", ResourceGroups.Count());
    }

    public async Task OnPostAsync()
    {
        
        var form = await Request.ReadFormAsync();
        var files = form.Files;
        var resourceGroups = form["ddlResourceGroups"];
        var resourceGroup = resourceGroups[0];
        var randomFileName = string.Empty;
        foreach (var formFile in files)
        {
            if (formFile.Length > 0)
            {
                randomFileName = Path.GetRandomFileName();
                var filePath = Path.Combine(environment.WebRootPath, randomFileName);

                await using var stream = System.IO.File.Create(filePath);
                await formFile.CopyToAsync(stream);
            }
        }

        if (!string.IsNullOrEmpty(randomFileName))
        {
            logger.LogInformation("Uploading jMeter file {FileName} to Azure Load Test", randomFileName);
            var altService = new ALTService(new AzurePowerShellCredential());
            var loadTestingResource = await altService.GetLoadTestingResourceAsync(resourceGroup);
            //TODO: upload
        }
    }


    [BindProperty] public List<ResourceGroupViewModel> ResourceGroups { get; set; } = new();
    [TempData] [BindProperty] public string Message { get; set; }
}