﻿using System;
using System.Diagnostics;
using System.Text;
using System.Threading.Tasks;
using Azure.Storage.Blobs;

namespace ITS.Generate.HtmlReports;

public class BlobStorageHelper
{
    private readonly string storageConnectionString;

    public BlobStorageHelper(string storageConnectionString) =>
        this.storageConnectionString = storageConnectionString;

    public async Task<string> GetReportHtmlAsync(string container, string name)
    {
        var blobServiceClient = new BlobServiceClient(storageConnectionString);
        var containerClient = blobServiceClient.GetBlobContainerClient(container);
        if (!await containerClient.ExistsAsync()) return string.Empty;

        var blobClient = containerClient.GetBlobClient(name);
        var blob = await blobClient.DownloadContentAsync();
        if (!blob.HasValue) return string.Empty;

        var template = Encoding.UTF8.GetString(blob.Value.Content.ToArray());
        return template;
    }

    public async Task<bool> SaveReportAsync(string containerName, string name, string content)
    {
        var blobServiceClient = new BlobServiceClient(storageConnectionString);
        var containerClient = blobServiceClient.GetBlobContainerClient(containerName);
        if (!await containerClient.ExistsAsync())
            await containerClient.CreateIfNotExistsAsync();

        var blobClient = containerClient.GetBlobClient(name);

        try
        {
            await blobClient.UploadAsync(new BinaryData(content), true);
            return true;
        }
        catch (Exception e)
        {
            Debug.WriteLine(e.Message);
            return false;
        }
    }
}