﻿using System;
using System.IO;
using System.Text;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Azure.WebJobs;
using Microsoft.Azure.WebJobs.Extensions.Http;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Logging;

namespace ITS.Generate.HtmlReports;

public class FileStatsHtmlReportWebhook
{
    [FunctionName("FileStatsHtmlReportWebhook")]
    public async Task<IActionResult> RunWhenCalledFromExternal(
        [HttpTrigger(AuthorizationLevel.Function, "get", Route = "latest-report")]
        HttpRequest req, ILogger log)
    {
        log.LogInformation("Reading template from storage at {DateStarted}", DateTime.Now);

        //create HTML report and save it to public container reports
        var storageConnectionString = Environment.GetEnvironmentVariable("AzureWebJobsStorage");
        var blobStorageHelper = new BlobStorageHelper(storageConnectionString);
        var reportTemplateName = Environment.GetEnvironmentVariable("TemplateName");
        var reportsContainer = Environment.GetEnvironmentVariable("ReportContainerName");
        var report = await blobStorageHelper.GetReportHtmlAsync(reportsContainer, reportTemplateName);
        //convert to bytes
        var bytes = Encoding.UTF8.GetBytes(report);
        using var ms = new MemoryStream();
        ms.Write(bytes, 0, bytes.Length);
        ms.Position = 0;
        return new FileContentResult(bytes, "text/html");
    }
}