﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Threading.Tasks;
using ITS.Models;
using Microsoft.Azure.WebJobs;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;

namespace ITS.Generate.HtmlReports;

public class FileStatsHtmlReports
{
    [FunctionName("FileStatsHtmlReports")]
    public async Task RunWhenFileStatsContainerChanges([BlobTrigger("files/{name}", Connection = "")] Stream myBlob,
        string name, ILogger log)
    {
        log.LogInformation($"WorkFileStats file updated\n Name of the blob:{name} \n Size: {myBlob.Length} Bytes");

        var serializer = new JsonSerializer();
        using var sr = new StreamReader(myBlob);
        await using var jsonTextReader = new JsonTextReader(sr);
        var list = serializer.Deserialize<List<WorkTaskStats>>(jsonTextReader);
        log.LogInformation("Read work stats {WorkTaskCount}", list.Count);
        //create HTML report and save it to public container reports
        var storageConnectionString = Environment.GetEnvironmentVariable("AzureWebJobsStorage");
        var blobStorageHelper = new BlobStorageHelper(storageConnectionString);
        var reportTemplateName = Environment.GetEnvironmentVariable("TemplateName");
        var reportTemplateContainer = Environment.GetEnvironmentVariable("TemplateContainerName");
        var report = await blobStorageHelper.GetReportHtmlAsync(reportTemplateContainer, reportTemplateName);
        log.LogInformation("{Report}", report);
        var table = "<table class='table'>";
        table += "<tr>";
        table += "<td>";
        table += "Most active task";
        table += "</td>";
        table += "<td>";
        table += "Closed tasks";
        table += "</td>";
        table += "<td>";
        table += "Public tasks";
        table += "</td>";
        table += "</tr>";
        foreach (var currentWorkItem in list)
        {
            table += "<tr>";
            table += "<td>";
            table += currentWorkItem.MostActiveTask.Description;
            table += "</td>";
            table += "<td>";
            table += currentWorkItem.ClosedTasks;
            table += "</td>";
            table += "<td>";
            table += currentWorkItem.PublicTasks;
            table += "</td>";
            table += "</tr>";
        }

        table += "</table>";
        report = report.Replace("#####", table);
        var reportsContainer = Environment.GetEnvironmentVariable("ReportContainerName");
        var reportsName = Environment.GetEnvironmentVariable("ReportName");
        log.LogInformation("Saving {ReportName} to {ReportContainer}", reportsName, reportsContainer);
        await blobStorageHelper.SaveReportAsync(reportsContainer, reportsName, report);
        log.LogInformation("Finished generating report {ReportName}", reportsName);
    }
}