﻿using ITS.Core;
using ITS.Web.Base;
using ITS.Web.Options;
using ITS.Web.Pages.Info;
using ITS.Web.Services;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Options;
using Moq;

namespace ITS.Tests;

[TestFixture(Description = "Initial tests for webpages")]
public class ItsWebPagesTests
{
    private readonly Mock<IUserDataContext> userDataContextMock = new();
    private readonly Mock<ILogger<IndexPageModel>> indexPageModelLogger = new();
    private readonly ReportingHttpServiceMock reportingHttpServiceMock;
    private readonly HttpClient httpClient = new();

    public ItsWebPagesTests()
    {
        var optionsApi = new Mock<IOptions<ApiOptions>>();
        optionsApi.Setup(optionsApi => optionsApi.Value).Returns(new ApiOptions
        {
            ReportApiUrl = "http://localhost/reportingapi/"
        });
        var authApi = new Mock<IOptions<AuthOptions>>();
        authApi.Setup(apiOp => apiOp.Value).Returns(new AuthOptions
        {
            ApiKey = "SomeApiKey",
            HashSalt = "SomeHashSalt"
        });

        var reportingHttpApiLogger = new Mock<ILogger<ReportApiHttpService>>();
        reportingHttpServiceMock =
            new ReportingHttpServiceMock(httpClient, optionsApi.Object, authApi.Object,
                reportingHttpApiLogger.Object);
    }

    [Test(Description = "Testing the indexpage get get's name of the machine")]
    [TestCase("ZERATULWIN")]
    [TestCase("ARTANIS")]
    [TestCase("VADER")]
    public void CheckIndexPageModelWithServerName(string computerName)
    {
        var ipm = new IndexPageModel(reportingHttpServiceMock,
            userDataContextMock.Object,
            indexPageModelLogger.Object)
        {
            ServerName = computerName
        };
        Assert.That(ipm.ServerName, Is.Not.Empty, "Server name is not null");
        Assert.That(ipm.ServerName, Is.AnyOf(Environment.MachineName, "ARTANIS", "VADER"),
            $"Machine name is equal to {Environment.MachineName}");
    }
}

internal class ReportingHttpServiceMock : ReportApiHttpService
{
    public ReportingHttpServiceMock(HttpClient client, IOptions<ApiOptions> apiOptionsValue,
        IOptions<AuthOptions> authOptionsValue, ILogger<ReportApiHttpService> logger) : base(client, apiOptionsValue,
        authOptionsValue, logger)
    {
    }
}