using System.Text.RegularExpressions;
using Microsoft.Playwright;
using Microsoft.Playwright.NUnit;

namespace ITS.Tests;

[Parallelizable(ParallelScope.Self)]
[TestFixture(Description = "Initial test to check if routes works as expected")]
public class TitlesAndRoutesTests : PageTest
{
    private string urlToTest;
    [SetUp]
    public void Init() => 
        urlToTest = Environment.GetEnvironmentVariable("WebUrl") ?? "https://localhost:5008";

    [Test]
    public async Task HomepageHasTitleHomePage()
    {
        await Page.GotoAsync(urlToTest);
        await Expect(Page).ToHaveTitleAsync(new Regex("Home page"));
    }

    [Test]
    public async Task TaskSearchHasTitleTaskSearchEngine()
    {
        await Page.GotoAsync($"{urlToTest}/tasks", new PageGotoOptions
        {
            Timeout = 60000, //expect long load
            WaitUntil = WaitUntilState.DOMContentLoaded
        });
        await Expect(Page).ToHaveTitleAsync(new Regex("Task search engine"));
    }
    
    [Test(Description = "Checking different values and routes id's")]
    [TestCase(76)]
    [TestCase(32)]
    [TestCase(100)]
    public async Task TaskDetailsTitleTaskDetailsForTask(int workTaskId)
    {
        await Page.GotoAsync($"https://{urlToTest}/Tasks/Details/{workTaskId}");
        await Expect(Page).ToHaveTitleAsync(new Regex($"Details for task {workTaskId}"));
    }
}